@@ -10,10 +10,11 @@
 using namespace Practice;
 
 AudioButton::AudioButton(QWidget *parent)
-    : QToolButton(parent), m_player(0)
+    : QToolButton(parent)
+    , m_player(nullptr)
 {
     setEnabled(false);
-    QIcon setIcon(QIcon::fromTheme(QStringLiteral("media-playback-start")));
+    setIcon(QIcon::fromTheme(QStringLiteral("media-playback-start")));
     setText(i18n("Play"));
     setToolTip(i18n("Play"));
     connect(this, &AudioButton::clicked, this, &AudioButton::playAudio);
@@ -29,7 +30,7 @@ void AudioButton::setSoundFile(const QUrl &soundFile)
 void AudioButton::playAudio()
 {
     if (!m_player) {
-        m_player = new QMediaPlayer( this );
+        m_player = new QMediaPlayer(this);
         connect(m_player, &QMediaPlayer::stateChanged, this, &AudioButton::playerStateChanged);
     } else {
         if (m_player->state() == QMediaPlayer::PlayingState) {
@@ -64,3 +65,5 @@ void AudioButton::playerStateChanged(QMediaPlayer::State newState)
         break;
     }
 }
+
+#include "moc_audiobutton.cpp"
